@@ -82,6 +82,17 @@ def check_rcfile():
             cfg.del_key("%s/countin_perc" % s)
             cfg.del_key("%s/rhythm_perc" % s)
     cfg.set_int("app/rcfileversion", rcfileversion)
+    try:
+        a = mpd.notename_to_int(cfg.get_string("user/lowest_pitch"))
+        b = mpd.notename_to_int(cfg.get_string("user/highest_pitch"))
+    except mpd.InvalidNotenameException:
+        if cfg.get_string("user/sex") == "male":
+            cfg.set_string("user/highest_pitch", "e'")
+            cfg.set_string("user/lowest_pitch", "c")
+        else:
+            cfg.set_string("user/highest_pitch", "e''")
+            cfg.set_string("user/lowest_pitch", "c'")
+
 
 class SolfegeApp(cfg.ConfigUtils):
     def __init__(self, options, ui, lessonfile_manager):
@@ -497,7 +508,7 @@ It is also possible that the OS sound setup is incorrect.
             # quick hack to use this for both melodic and harmonic intervals
             if module == 'melodicinterval':
                 teacher.m_interval = teacher.m_question[0]
-            teacher.q_status = self.QSTATUS_SOLVED
+            teacher.q_status = teacher.QSTATUS_SOLVED
             ret = {'question': {}, 'answer': {}}
             if sdict['qtype'] == 0:
                 ret['question']['name'] = "...."
