@@ -169,7 +169,7 @@ class MyTextView(gtk.TextView):
             b.create_tag('li-%i' % level,
                 left_margin=self.indent_step*level+30, indent=self.list_dot_indent)
         for n, fontsize in (1, 16), (2, 15), (3, 14), (4, 12), (5, 11), (6, 10):
-            b.create_tag('h%i' % n, weight=pango.WEIGHT_BOLD, font='Sans %i' % fontsize, pixels_above_lines=fontsize)
+            b.create_tag('h%i' % n, weight=pango.WEIGHT_BOLD, size=fontsize*pango.SCALE, pixels_above_lines=fontsize)
         b.create_tag('b', weight=pango.WEIGHT_BOLD)
         b.create_tag('strong', weight=pango.WEIGHT_BOLD)
         b.create_tag('em', style=pango.STYLE_ITALIC)
