@@ -1,11 +1,13 @@
+# vim: set fileencoding=utf-8 :
 # Solfege - free ear training software
-# Copyright (C) 2007 Tom Cato Amundsen
+# Copyright (C) 2007, 2008 Tom Cato Amundsen
 # License is GPL, see file COPYING
 
 import unittest
 import traceback
+import codecs
 
-from src.testlib import I18nSetup
+from src.testlib import I18nSetup, outdir
 from src.dataparser import *
 import src.i18n
 import os
@@ -53,6 +55,67 @@ var = 3
                               "(line 2): question { a = 3} |!\n"
                               "                            ^",
                               e.m_nonwrapped_text)
+    def test_encodings_utf8(self):
+        s = """
+        name = "øæå" """
+        f = codecs.open(os.path.join(outdir, "file1"), 'w', 'utf-8')
+        f.write(s)
+        f.close()
+        f = open(os.path.join(outdir, "file1"), 'rU')
+        s = f.read()
+        f.close()
+        p = Dataparser({}, {})
+        p._lexer = Lexer(s, p)
+        self.assertEquals(p._lexer.m_tokens[2][1], "øæå")
+    def test_encodings_iso88591(self):
+        s = '#vim: set fileencoding=iso-8859-1 : \n' \
+            'name = "øæå" '
+        f = codecs.open(os.path.join(outdir, "file1"), 'w', 'iso-8859-1')
+        f.write(s)
+        f.close()
+        f = open(os.path.join(outdir, "file1"), 'rU')
+        s = f.read()
+        f.close()
+        p = Dataparser({}, {})
+        p._lexer = Lexer(s, p)
+        self.assertEquals(p._lexer.m_tokens[2][1], "øæå")
+    def test_encodings_delcar_not_first(self):
+        s = '#\n#\n#vim: set fileencoding=iso-8859-1 : \n' \
+            'name = "øæå" '
+        f = codecs.open(os.path.join(outdir, "file1"), 'w', 'iso-8859-1')
+        f.write(s)
+        f.close()
+        f = open(os.path.join(outdir, "file1"), 'rU')
+        s = f.read()
+        f.close()
+        self.assertRaises(UnableToTokenizeException,
+            lambda: Lexer(s, Dataparser({}, {})))
+    def test_missing_encoding_definition_iso88591(self):
+        """
+        We write a simple datafile in iso-8859-1 encoding, but does not
+        add the encoding line. The dataparser will assume files are utf-8
+        by default, and will fail to tokenize.
+        """
+        s = 'name = "øæå" '
+        f = codecs.open(os.path.join(outdir, "file1"), 'w', 'iso-8859-1')
+        f.write(s)
+        f.close()
+        f = open(os.path.join(outdir, "file1"), 'rU')
+        s = f.read()
+        f.close()
+        self.assertRaises(UnableToTokenizeException,
+            lambda: Lexer(s, Dataparser({}, {})))
+    def test_X(self):
+        s = r"""
+question {
+   music = music("\staff \stemUp  {
+   \clef violin \key d \minor \time 4/4
+    c4
+    }a")
+}
+"""
+        p = Dataparser({}, {})
+        p._lexer = Lexer(s, p)
 
 class TestDataParser(I18nSetup):
     def test_for_trainingset(self):
@@ -169,10 +232,10 @@ class TestDataParser(I18nSetup):
         p.parse_string("""
          question {
            var = "var-C"
-           var[no] = "var-no"
+           var[nb] = "var-nb"
          }
         """)
-        self.assertEquals(p.questions[0]['var'], u'var-no')
+        self.assertEquals(p.questions[0]['var'], u'var-nb')
         self.assert_(isinstance(p.questions[0]['var'], istr))
         self.assertEquals(p.questions[0]['var'].cval, u'var-C')
     def test_istr_translations_in_file2(self):
@@ -203,38 +266,47 @@ class TestDataParser(I18nSetup):
              }
             """)
         self.assertRaises(CannotTranslateListsException, f)
+    def test_unsupported_named_block(self):
+        p = Dataparser({}, {'_': dataparser_i18n_func})
+        def f():
+            p.parse_string("""
+nonnamed header { 
+    name  = "File with random chars"
+}
+            """)
+        self.assertRaises(DataparserSyntaxError, f)
 
 class TestIstr(I18nSetup):
     def test_musicstr(self):
         s = istr(r"\staff{ c e g }")
         self.assert_(isinstance(s, basestring))
     def test_add_translations1(self):
-        #i18n.langs: no_NO, no, C
+        #i18n.langs: nb_NO, nb, C
         # name = "Yes"
         # name[no] = "Ja"
         s = "Yes"
         s = istr(s)
         self.assertEquals(unicode(s), u'Yes')
-        s = s.add_translation('no', 'Ja')
+        s = s.add_translation('nb', 'Ja')
         self.assertEquals(s, u'Ja')
-        s = s.add_translation('no_NO', 'Ja!')
+        s = s.add_translation('nb_NO', 'Ja!')
         self.assertEquals(s, u'Ja!')
     def test_add_translations2(self):
-        #i18n.langs: no_NO, no, C
+        #i18n.langs: nb_NO, nb, C
         # name = "Yes"
         # name[no] = "Ja"
         s = "Yes"
         s = istr(s)
         self.assertEquals(s, u'Yes')
-        s = s.add_translation('no_NO', 'Ja!')
+        s = s.add_translation('nb_NO', 'Ja!')
         self.assertEquals(s, u'Ja!')
-        s = s.add_translation('no', 'Ja')
+        s = s.add_translation('nb', 'Ja')
         self.assertEquals(s, u'Ja!', "Should still be 'Ja!' because no_NO is preferred before no")
     def test_override_gettext(self):
         s = dataparser_i18n_func("major")
         self.assertEquals(s, "dur")
         self.assertEquals(s.cval, "major")
-        s = s.add_translation('no', "Dur")
+        s = s.add_translation('nb', "Dur")
         self.assertEquals(s, u"Dur")
     def test_type(self):
         s = istr("jo")
