@@ -86,7 +86,9 @@ class TracebackWindow(gtk.Dialog):
         if ("DeprecationWarning:" in txt) or \
            (not self.m_show_gtk_warnings and (
             "GtkWarning" in txt or
-            "PangoWarning" in txt)):
+            "PangoWarning" in txt or
+            "Python C API version mismatch for module _solfege_c_midi" in txt
+            )):
             print txt
             return
         sys.stdout.write(txt)
