@@ -13,13 +13,16 @@ import src
 import gnome.ui
 import mpd, mpd.musicdisplayer, soundcard
 import gtk
-from src import gu, cfg
-cfg.initialise(None, None, 'mpd-test')
 import src.utils
+from src import gu
+
+musicfile = "mpd-test.txt"
 
 class DisplaytestWindow(gtk.Window):
     def on_quit(self, w):
-        cfg.sync()
+        t = self.m_buf.get_text(self.m_buf.get_start_iter(),
+                                self.m_buf.get_end_iter(), True)
+        self.save(t)
     def __init__(self):
         gtk.Window.__init__(self)
         self.connect('destroy', self.on_quit)
@@ -30,8 +33,9 @@ class DisplaytestWindow(gtk.Window):
         self.g_text.set_size_request(-1, 100)
         self.g_text.show()
         self.g_text.set_editable(True)
-        s = cfg.get_string('config/score_displayer')
-        if not s:
+        try:
+            s = open(musicfile, "r").read()
+        except IOError, e:
             s = r"\staff{c' d' e'}"
         self.m_buf = self.g_text.get_buffer()
         self.m_buf.insert(self.m_buf.get_end_iter(), s)
@@ -46,6 +50,10 @@ class DisplaytestWindow(gtk.Window):
         #gu.bButton(vbox, "Display last notes", self.on_display_last_notes)
         gu.bButton(vbox, "Play", self.on_play)
         gu.bButton(vbox, "Play first", self.on_play_first)
+    def save(self, text):
+        f = open(musicfile, 'w')
+        f.write(text)
+        f.close()
     def on_parse(self, _o):
         t = self.m_buf.get_text(self.m_buf.get_start_iter(),
                                 self.m_buf.get_end_iter(), True)
@@ -53,22 +61,22 @@ class DisplaytestWindow(gtk.Window):
     def on_display(self, _o):
         t = self.m_buf.get_text(self.m_buf.get_start_iter(),
                                 self.m_buf.get_end_iter(), True)
-        cfg.set_string('config/score_displayer', t)
+        self.save(t)
         self.g_displayer.display(t, 20)
     def on_display_first_notes(self, _o):
         t = self.m_buf.get_text(self.m_buf.get_start_iter(),
                                 self.m_buf.get_end_iter(), True)
-        cfg.set_string('config/score_displayer', t)
+        self.save(t)
         self.g_displayer.display(t, 20, mpd.FIRST)
     def on_display_last_notes(self, _o):
         t = self.m_buf.get_text(self.m_buf.get_start_iter(),
                                 self.m_buf.get_end_iter(), True)
-        cfg.set_string('config/score_displayer', t)
+        self.save(t)
         self.g_displayer.display(t, 20, mpd.LAST)
     def on_play(self, _o):
         t = self.m_buf.get_text(self.m_buf.get_start_iter(),
                                 self.m_buf.get_end_iter(), True)
-        cfg.set_string('config/score_displayer', t)
+        self.save(t)
         mpd.play_music(t, (120, 4), 0, 100)
     def on_play_first(self, _o):
         t = self.m_buf.get_text(self.m_buf.get_start_iter(),
